@@ -1,4 +1,4 @@
-from typing import Any, cast
+from typing import Any
 
 try:
     from redis.asyncio import Redis
@@ -23,4 +23,4 @@ def create_async_redis_client(
         decode_responses=decode_responses,
         **kwargs,
     )
-    return cast(Redis, redis)
+    return redis
